Post

Trait Post 

pub trait Post: Send + 'static { }
Types that can be sent to another thread. In this shim, this trait is just an alias for Send + 'static, but in web-thread some types can be sent only by performing an explicit transfer operation.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<T: Send + 'static> Post for T